@@ -1,8 +1,5 @@
 #pragma once
 
-#ifndef FASTFETCH_INCLUDED
-#define FASTFETCH_INCLUDED
-
 #include "fastfetch_config.h"
 
 #include <stdint.h>
@@ -28,6 +25,16 @@
 #include "options/display.h"
 #include "options/general.h"
 
+#ifdef __has_builtin
+    #if __has_builtin(__builtin_types_compatible_p)
+        #define ARRAY_SIZE(x) ({ static_assert(!__builtin_types_compatible_p(__typeof__(x), __typeof__(&*(x))), "Must not be a pointer"); sizeof(x) / sizeof(*(x)); })
+    #endif
+#endif
+#ifndef ARRAY_SIZE
+    #define ARRAY_SIZE(x) (sizeof(x) / sizeof(*(x)))
+#endif
+
+
 typedef struct FFconfig
 {
     FFOptionsLogo logo;
@@ -80,5 +87,3 @@ void ffLogoPrintLine();
 void ffLogoBuiltinPrint();
 void ffLogoBuiltinList();
 void ffLogoBuiltinListAutocompletion();
-
-#endif
