@@ -10,7 +10,7 @@
 
 #include <stdlib.h>
 
-#define FF_GPU_NUM_FORMAT_ARGS 12
+#define FF_GPU_NUM_FORMAT_ARGS 13
 
 static void printGPUResult(FFGPUOptions* options, uint8_t index, const FFGPUResult* gpu)
 {
@@ -103,6 +103,7 @@ static void printGPUResult(FFGPUOptions* options, uint8_t index, const FFGPUResu
             FF_FORMAT_ARG(sUsed, "shared-used"),
             FF_FORMAT_ARG(gpu->platformApi, "platform-api"),
             FF_FORMAT_ARG(frequency, "frequency"),
+            FF_FORMAT_ARG(index, "index"),
         }));
     }
 }
@@ -322,6 +323,12 @@ void ffGenerateGPUJsonResult(FFGPUOptions* options, yyjson_mut_doc* doc, yyjson_
     FF_LIST_FOR_EACH(FFGPUResult, gpu, gpus)
     {
         yyjson_mut_val* obj = yyjson_mut_arr_add_obj(doc, arr);
+
+        if (gpu->index != FF_GPU_INDEX_UNSET)
+            yyjson_mut_obj_add_uint(doc, obj, "index", gpu->index);
+        else
+            yyjson_mut_obj_add_null(doc, obj, "index");
+
         if (gpu->coreCount != FF_GPU_CORE_COUNT_UNSET)
             yyjson_mut_obj_add_int(doc, obj, "coreCount", gpu->coreCount);
         else
@@ -402,6 +409,7 @@ void ffPrintGPUHelpFormat(void)
         "GPU used shared memory - shared-used",
         "The platform API used when detecting the GPU - platform-api",
         "Current frequency in GHz - frequency",
+        "GPU vendor specific index - index",
     }));
 }
 
